@@ -14,10 +14,10 @@ which is often used for CV tasks such as semantic segmentation.
 
 from typing import Any, Dict, Iterable, Optional, Type, TypeVar
 
-from ..geometry import RLE, MultiPolygon, Polygon
-from ..utility import ReprType, attr_base, common_loads
-from .basic import SubcatalogBase, _LabelBase
-from .supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
+from tensorbay.geometry import RLE, MultiPolygon, Polygon
+from tensorbay.label.basic import SubcatalogBase, _LabelBase
+from tensorbay.label.supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
+from tensorbay.utility import ReprType, attr_base, common_loads
 
 
 class PolygonSubcatalog(SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin):
@@ -201,7 +201,7 @@ class RLESubcatalog(SubcatalogBase, IsTrackingMixin, CategoriesMixin, Attributes
         IsTrackingMixin.__init__(self, is_tracking)
 
 
-class LabeledPolygon(_LabelBase, Polygon):  # pylint: disable=too-many-ancestors
+class LabeledPolygon(_LabelBase, Polygon):
     """This class defines the concept of polygon label.
 
     :class:`LabeledPolygon` is the polygon type of label,
@@ -314,9 +314,7 @@ class LabeledPolygon(_LabelBase, Polygon):  # pylint: disable=too-many-ancestors
         return self._dumps()
 
 
-class LabeledMultiPolygon(  # type: ignore[misc]
-    _LabelBase, MultiPolygon
-):  # pylint: disable=too-many-ancestors
+class LabeledMultiPolygon(_LabelBase, MultiPolygon):  # type: ignore[misc]
     """This class defines the concept of multiple polygon label.
 
     :class:`LabeledMultiPolygon` is the multipolygon type of label,
@@ -432,7 +430,7 @@ class LabeledMultiPolygon(  # type: ignore[misc]
         return self._dumps()
 
 
-class LabeledRLE(_LabelBase, RLE):  # type: ignore[misc]  # pylint: disable=too-many-ancestors
+class LabeledRLE(_LabelBase, RLE):  # type: ignore[misc]
     """This class defines the concept of rle label.
 
     :class:`LabeledRLE` is the rle type of label,
