@@ -3,11 +3,12 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 # pylint: disable=invalid-name
-# pylint: disable=missing-module-docstring
+
+"""Dataloaders of AnimalPose5 dataset and AnimalPose7 dataset."""
 
 import json
 import os
-from typing import Iterable, Iterator, List, Tuple
+from typing import Any, Iterable, Iterator, List, Tuple
 
 from tensorbay.dataset import Data, Dataset
 from tensorbay.exception import ModuleImportError
@@ -114,7 +115,7 @@ def _get_data_part1(root_path: str, aniamls: Iterable[str]) -> Iterator[Data]:
             ):
 
                 with open(annotation_path, encoding="utf-8") as fp:
-                    labels = xmltodict.parse(fp.read())
+                    labels: Any = xmltodict.parse(fp.read())
 
                 box2d = labels["annotation"]["visible_bounds"]
                 data.label.box2d = [
@@ -157,7 +158,7 @@ def _get_data_part2(root_path: str, aniamls: Iterable[str]) -> Iterator[Data]:
             )
 
             with open(annotation_path, encoding="utf-8") as fp:
-                labels = xmltodict.parse(fp.read())
+                labels: Any = xmltodict.parse(fp.read())
 
             box2d = labels["annotation"]["visible_bounds"]
             data.label.box2d = [
