@@ -4,7 +4,7 @@
 #
 # pylint: disable=invalid-name
 
-"""Dataloader of the 17 Category Flower dataset and the 102 Category Flower dataset."""
+"""Dataloaders of the 17 Category Flower dataset and the 102 Category Flower dataset."""
 
 from tensorbay.opendataset.Flower.loader import Flower17, Flower102
 
