@@ -3,7 +3,8 @@
 # Copytright 2021 Graviti. Licensed under MIT License.
 #
 # pylint: disable=invalid-name
-# pylint: disable=missing-module-docstring
+
+"""Dataloader of RP2K dataset."""
 
 import os
 from glob import glob
