@@ -4,18 +4,24 @@
 #
 # pylint: disable=missing-module-docstring, invalid-name
 
+from typing import Any
+
 from tensorbay.exception import ModuleImportError
 
 
-class Image:
+class ImageMocker:
     """Raise import PIL error for data loader."""
 
-    def __getattribute__(self, name: str) -> None:
+    def __getattribute__(self, name: str) -> Any:
         raise ModuleImportError(module_name="pillow")
 
 
-class xmltodict:
+class xmltodictMocker:
     """Raise import xmltodict error for data loader."""
 
-    def __getattribute__(self, name: str) -> None:
+    def __getattribute__(self, name: str) -> Any:
         raise ModuleImportError(module_name="xmltodict")
+
+
+Image = ImageMocker()
+xmltodict = xmltodictMocker()
