@@ -33,14 +33,14 @@ from typing import (
     overload,
 )
 
-from .repr import ReprMixin, ReprType
+from tensorbay.utility.repr import ReprMixin, ReprType
 
 _T = TypeVar("_T")
 _K = TypeVar("_K")
 _V = TypeVar("_V")
 
 
-class UserSequence(Sequence[_T], ReprMixin):  # pylint: disable=too-many-ancestors
+class UserSequence(Sequence[_T], ReprMixin):
     """UserSequence is a user-defined wrapper around sequence objects."""
 
     _data: Sequence[_T]
@@ -61,9 +61,21 @@ class UserSequence(Sequence[_T], ReprMixin):  # pylint: disable=too-many-ancesto
     def __getitem__(self, index: Union[int, slice]) -> Union[Sequence[_T], _T]:
         return self._data.__getitem__(index)
 
+    def __contains__(self, value: Any) -> bool:
+        return self._data.__contains__(value)
+
     def __iter__(self) -> Iterator[_T]:
         return self._data.__iter__()
 
+    def __reversed__(self) -> Iterator[_T]:
+        return self._data.__reversed__()
+
+    def __eq__(self, other: Any) -> bool:
+        if not isinstance(other, self.__class__):
+            return False
+
+        return self._data.__eq__(other._data)
+
     def index(self, value: _T, start: int = 0, stop: int = maxsize) -> int:
         """Return the first index of the value.
 
@@ -91,16 +103,13 @@ class UserSequence(Sequence[_T], ReprMixin):  # pylint: disable=too-many-ancesto
         return self._data.count(value)
 
 
-class UserMutableSequence(MutableSequence[_T], ReprMixin):  # pylint: disable=too-many-ancestors
+class UserMutableSequence(MutableSequence[_T], UserSequence[_T]):
     """UserMutableSequence is a user-defined wrapper around mutable sequence objects."""
 
     _data: MutableSequence[_T]
 
     _repr_type = ReprType.SEQUENCE
 
-    def __len__(self) -> int:
-        return self._data.__len__()
-
     @overload
     def __getitem__(self, index: int) -> _T:
         ...
@@ -127,9 +136,6 @@ class UserMutableSequence(MutableSequence[_T], ReprMixin):  # pylint: disable=to
     def __delitem__(self, index: Union[int, slice]) -> None:
         self._data.__delitem__(index)
 
-    def __iter__(self) -> Iterator[_T]:
-        return self._data.__iter__()
-
     def __iadd__(self, value: Iterable[_T]) -> MutableSequence[_T]:
         return self._data.__iadd__(value)
 
@@ -191,7 +197,7 @@ class UserMutableSequence(MutableSequence[_T], ReprMixin):  # pylint: disable=to
         self._data.remove(value)
 
 
-class UserMapping(Mapping[_K, _V], ReprMixin):  # pylint: disable=too-many-ancestors
+class UserMapping(Mapping[_K, _V], ReprMixin):
     """UserMapping is a user-defined wrapper around mapping objects."""
 
     _data: Mapping[_K, _V]
@@ -210,6 +216,12 @@ class UserMapping(Mapping[_K, _V], ReprMixin):  # pylint: disable=too-many-ances
     def __iter__(self) -> Iterator[_K]:
         return self._data.__iter__()
 
+    def __eq__(self, other: Any) -> bool:
+        if not isinstance(other, self.__class__):
+            return False
+
+        return self._data.__eq__(other._data)
+
     @overload
     def get(self, key: _K) -> Optional[_V]:  # pylint: disable=arguments-differ
         ...
@@ -259,9 +271,7 @@ class UserMapping(Mapping[_K, _V], ReprMixin):  # pylint: disable=too-many-ances
         return self._data.values()
 
 
-class UserMutableMapping(
-    UserMapping[_K, _V], MutableMapping[_K, _V]
-):  # pylint: disable=too-many-ancestors
+class UserMutableMapping(MutableMapping[_K, _V], UserMapping[_K, _V]):
     """UserMutableMapping is a user-defined wrapper around mutable mapping objects."""
 
     __marker = object()
